<?xml version="1.0" ?><!DOCTYPE TS><TS language="id" version="2.0">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <location filename="src/AboutView.cpp" line="21"/>
        <source>There&apos;s life outside the browser!</source>
        <translation>Hidup diluarnya browser!</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="22"/>
        <source>Version %1</source>
        <translation>Version %1</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="26"/>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 is Free Software but its development takes precious time.</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="27"/>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Silahkan &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; untuk mendukung kelanjutan pangembangannya dari %2.</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="31"/>
        <source>You may want to try my other apps as well:</source>
        <translation>Anda mungkin ingin untuk mencoba aplikasiku yang lainnya:</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="34"/>
        <source>%1, a YouTube music player</source>
        <translation>%1, suatu pemutar musik YouTube</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="38"/>
        <source>%1, a music player</source>
        <translation>%1, suatu pemutar musik</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="44"/>
        <source>Translate %1 to your native language using %2</source>
        <translation>Terjemahkan %1 ke bahasa aslimu gunakan %2</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="49"/>
        <source>Icon designed by %1.</source>
        <translation>Desain ikon oleh %1.</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="53"/>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Dirilis dibawah the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="src/AboutView.cpp" line="65"/>
        <source>&amp;Close</source>
        <translation>&amp;Tutup</translation>
    </message>
    <message>
        <location filename="src/AboutView.h" line="25"/>
        <source>About</source>
        <translation>Tentang</translation>
    </message>
    <message>
        <location filename="src/AboutView.h" line="27"/>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Apa kamu selalu ingin untuk mengetahui tentangnya %1 dan tidak pernah berani untuk bertanya</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <location filename="src/searchlineedit.cpp" line="56"/>
        <source>Clear</source>
        <translation>Bersih</translation>
    </message>
</context>
<context>
    <name>DemoStartupView</name>
    <message>
        <location filename="local/src/demostartupview.cpp" line="35"/>
        <source>Please license %1</source>
        <translation>Silahkan dilisensi %1</translation>
    </message>
    <message>
        <location filename="local/src/demostartupview.cpp" line="39"/>
        <source>This demo has expired.</source>
        <translation>Demo ini telah habis masa berlakunya.</translation>
    </message>
    <message>
        <location filename="local/src/demostartupview.cpp" line="41"/>
        <source>The full version allows you to download videos longer than %1 minutes and to watch videos without interruptions.</source>
        <translation>Versi lengkap memperbolehkan Anda untuk men-download video lebih dari %1 menit dan untuk menonton video tanpa disela.</translation>
    </message>
    <message>
        <location filename="local/src/demostartupview.cpp" line="43"/>
        <source>This demo will expire in %1 days.</source>
        <translation>Demo ini akan habis masa berlakunya dalam waktu %1 hari.</translation>
    </message>
    <message>
        <location filename="local/src/demostartupview.cpp" line="45"/>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Dengan membeli versi penuh, Anda juga akan didukung kerja keras Saya letakkan ke dalam kreasi %1.</translation>
    </message>
    <message>
        <location filename="local/src/demostartupview.cpp" line="57"/>
        <source>Use Demo</source>
        <translation>Gunakan Demo</translation>
    </message>
    <message>
        <location filename="local/src/demostartupview.cpp" line="65"/>
        <source>Get the full version</source>
        <translation>Dapatkan versi penuh</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <location filename="src/downloaditem.cpp" line="308"/>
        <source>bytes</source>
        <translation>bit</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="311"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="314"/>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="330"/>
        <source>bytes/sec</source>
        <translation>bit/dtk</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="333"/>
        <source>KB/sec</source>
        <translation>KB/detik</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="336"/>
        <source>MB/sec</source>
        <translation>MB/sec</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="342"/>
        <source>seconds</source>
        <translation>detik</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="345"/>
        <source>minutes</source>
        <translation>menit</translation>
    </message>
    <message>
        <location filename="src/downloaditem.cpp" line="348"/>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 sisanya</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <location filename="src/downloadmanager.cpp" line="47"/>
        <source>This is just the demo version of %1.</source>
        <translation>Ini adalah hanya versi demo dari %1.</translation>
    </message>
    <message>
        <location filename="src/downloadmanager.cpp" line="49"/>
        <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
        <translation>Itu bisanya hanya download video yang pendek daripada %1 menit sehingga kamu bisa menguji fungsinya downloadnya.</translation>
    </message>
    <message>
        <location filename="src/downloadmanager.cpp" line="55"/>
        <source>Continue</source>
        <translation>Teruskan</translation>
    </message>
    <message>
        <location filename="src/downloadmanager.cpp" line="56"/>
        <source>Get the full version</source>
        <translation>Dapatkan versi komplitnya</translation>
    </message>
    <message numerus="yes">
        <location filename="src/downloadmanager.cpp" line="137"/>
        <source>%n Download(s)</source>
        <translation><numerusform>%n Mendownload(s)</numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <location filename="src/downloadsettings.cpp" line="14"/>
        <source>Change location...</source>
        <translation>Ganti lokasi...</translation>
    </message>
    <message>
        <location filename="src/downloadsettings.cpp" line="38"/>
        <source>Choose the download location</source>
        <translation>Pilihlah lokasi unduhan</translation>
    </message>
    <message>
        <location filename="src/downloadsettings.cpp" line="49"/>
        <source>Download location changed.</source>
        <translation>Merubah lokasi unduhan.</translation>
    </message>
    <message>
        <location filename="src/downloadsettings.cpp" line="51"/>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Unduhan saat ini masih ingin pergi di lokasi sebelumnya.</translation>
    </message>
    <message>
        <location filename="src/downloadsettings.cpp" line="63"/>
        <source>Downloading to: %1</source>
        <translation>Unduhan ke: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <location filename="src/downloadview.cpp" line="18"/>
        <location filename="src/downloadview.h" line="22"/>
        <source>Downloads</source>
        <translation>Unduhan</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <location filename="src/globalshortcuts.cpp" line="16"/>
        <source>Play</source>
        <translation>Play</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="17"/>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="18"/>
        <source>Play/Pause</source>
        <translation>Mainkan/Jeda</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="19"/>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="20"/>
        <source>Stop playing after current track</source>
        <translation>Stop playing after current track</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="21"/>
        <source>Next track</source>
        <translation>Next track</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="22"/>
        <source>Previous track</source>
        <translation>Previous track</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="23"/>
        <source>Increase volume</source>
        <translation>Increase volume</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="24"/>
        <source>Decrease volume</source>
        <translation>Decrease volume</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="25"/>
        <source>Mute</source>
        <translation>Mute</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="26"/>
        <source>Seek forward</source>
        <translation>Seek forward</translation>
    </message>
    <message>
        <location filename="src/globalshortcuts.cpp" line="27"/>
        <source>Seek backward</source>
        <translation>Seek backward</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <location filename="src/ListModel.cpp" line="51"/>
        <source>Searching...</source>
        <translation>Pencarian...</translation>
    </message>
    <message>
        <location filename="src/ListModel.cpp" line="52"/>
        <source>Show %1 More</source>
        <translation>Tampilkan %1 More</translation>
    </message>
    <message>
        <location filename="src/ListModel.cpp" line="53"/>
        <source>No videos</source>
        <translation>No videos</translation>
    </message>
    <message>
        <location filename="src/ListModel.cpp" line="54"/>
        <source>No more videos</source>
        <translation>No more videos</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <location filename="src/loadingwidget.cpp" line="71"/>
        <source>Error</source>
        <translation>Gangguan</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="src/MainWindow.cpp" line="160"/>
        <source>&amp;Stop</source>
        <translation>&amp;Stop</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="161"/>
        <source>Stop playback and go back to the search view</source>
        <translation>Stop playback and go back to the search view</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="179"/>
        <source>S&amp;kip</source>
        <translation>S&amp;kip</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="180"/>
        <source>Skip to the next video</source>
        <translation>Skip to the next video</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="186"/>
        <location filename="src/MainWindow.cpp" line="835"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pause</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="187"/>
        <location filename="src/MainWindow.cpp" line="836"/>
        <source>Pause playback</source>
        <translation>Pause playback</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="193"/>
        <source>&amp;Full Screen</source>
        <translation>&amp;Full Screen</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="194"/>
        <source>Go full screen</source>
        <translation>Go full screen</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="210"/>
        <source>Hide the playlist and the toolbar</source>
        <translation>Hide the playlist and the toolbar</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="223"/>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Pergi ke halaman video YouTube dan jeda pemutaran</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="230"/>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Copy the current video YouTube link to the clipboard</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="237"/>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Copy the current video stream URL to the clipboard</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="244"/>
        <source>Find other video parts hopefully in the right order</source>
        <translation>Mencari bagian-bagian video yang lainnya diharapkan dalam pesanan yang benar</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="250"/>
        <source>&amp;Remove</source>
        <translation>&amp;Remove</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="251"/>
        <source>Remove the selected videos from the playlist</source>
        <translation>Remove the selected videos from the playlist</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="257"/>
        <source>Move &amp;Up</source>
        <translation>Move &amp;Up</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="258"/>
        <source>Move up the selected videos in the playlist</source>
        <translation>Gerakkan ke atas video yang dipilih dalam daftar-main</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="264"/>
        <source>Move &amp;Down</source>
        <translation>Move &amp;Down</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="265"/>
        <source>Move down the selected videos in the playlist</source>
        <translation>Gerakkan ke bawah video yang dipilih dalam daftar-main</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="276"/>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Menghapus sejarah pencarian. Tidak bisa dikembalikan.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="281"/>
        <source>&amp;Quit</source>
        <translation>&amp;Cabut</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="284"/>
        <source>Bye</source>
        <translation>Selamat tinggal</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="288"/>
        <source>&amp;Website</source>
        <translation>&amp;Situs web</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="290"/>
        <source>%1 on the Web</source>
        <translation>%1 pada Web</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="296"/>
        <source>Please support the continued development of %1</source>
        <translation>Please support the continued development of %1</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="301"/>
        <source>&amp;About</source>
        <translation>&amp;Tentang</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="303"/>
        <source>Info about %1</source>
        <translation>Info Tentang %1</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="311"/>
        <source>Search</source>
        <translation>Search</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="330"/>
        <source>Mute volume</source>
        <translation>Bisukan volume</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="359"/>
        <location filename="src/MainWindow.cpp" line="1179"/>
        <source>&amp;Downloads</source>
        <translation>&amp;Unduhan-unduhan</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="360"/>
        <source>Show details about video downloads</source>
        <translation>Tampilkan detail tentang unduhan-unduhan video</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="368"/>
        <source>&amp;Download</source>
        <translation>&amp;Unduhan</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="369"/>
        <source>Download the current video</source>
        <translation>Unduhan-unduhan video saat ini</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="381"/>
        <source>Share the current video using %1</source>
        <translation>Berbagi video saat ini gunakan %1</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="393"/>
        <source>&amp;Email</source>
        <translation>&amp;Surat</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="394"/>
        <source>Email</source>
        <translation>Surat</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="398"/>
        <source>&amp;Close</source>
        <translation>&amp;Tutup</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="403"/>
        <source>&amp;Float on Top</source>
        <translation>&amp;Mengambang ke puncak</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="408"/>
        <source>&amp;Stop After This Video</source>
        <translation>&amp;berhenti setelah video ini</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="445"/>
        <source>&amp;Application</source>
        <translation>&amp;Application</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="447"/>
        <source>Buy %1...</source>
        <translation>Beli %1...</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="458"/>
        <source>&amp;Playback</source>
        <translation>&amp;Putarbalik</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="472"/>
        <source>&amp;Playlist</source>
        <translation>&amp;Daftar-Main</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="479"/>
        <source>&amp;Video</source>
        <translation>&amp;Video</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="490"/>
        <source>&amp;View</source>
        <translation>&amp;Tampak</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="497"/>
        <source>&amp;Share</source>
        <translation>&amp;Berbagi</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="509"/>
        <source>&amp;Help</source>
        <translation>&amp;Help</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="586"/>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Tekan %1 untuk menambahkan volume, %2 untuk merendahkan itu</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="748"/>
        <location filename="src/MainWindow.cpp" line="754"/>
        <source>Opening %1</source>
        <translation>Membuka %1</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="787"/>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Do you want to exit %1 with a download in progress?</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="788"/>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Jika Anda menutup %1 sekarang, unduhan ini akan dibatalkan.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="793"/>
        <source>Close and cancel download</source>
        <translation>Tutup dan membatalkan unduhan</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="794"/>
        <source>Wait for download to finish</source>
        <translation>Menunggu unduhannya selesai</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="940"/>
        <source>Leave &amp;Full Screen</source>
        <translation>Tinggalkan &amp;Layar Penuh</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1283"/>
        <source>%1 version %2 is now available.</source>
        <translation>%1 versi %2 sekarang telah tersedia.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1297"/>
        <source>Remind me later</source>
        <translation>Beritahu saya lagi nanti</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1294"/>
        <source>To get the updated version, download %1 again from the link you received via email and reinstall.</source>
        <translation>Untuk mendapatkan versi terbaru, download %1 lagi dari link yang Anda terima melalui email dan pasangkan ulang.</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1301"/>
        <source>Update</source>
        <translation>Pembaruan data</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="828"/>
        <source>Error: %1</source>
        <translation>Error: %1</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="169"/>
        <source>P&amp;revious</source>
        <translation>S&amp;ebelumnya</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="170"/>
        <source>Go back to the previous track</source>
        <translation>Kembali lagi ke trek sebelumnya</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="209"/>
        <source>&amp;Compact Mode</source>
        <translation>&amp;Model kompak</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="222"/>
        <source>Open the &amp;YouTube Page</source>
        <translation>Buka &amp;Halaman YouTube</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="229"/>
        <source>Copy the YouTube &amp;Link</source>
        <translation>Salin YouTube &amp;Pintasan</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="236"/>
        <source>Copy the Video Stream &amp;URL</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="243"/>
        <source>Find Video &amp;Parts</source>
        <translation>Mencari Video &amp;Perkakas</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="271"/>
        <source>&amp;Clear Recent Searches</source>
        <translation>&amp;Bersihkan Jejak Pencarian</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="295"/>
        <source>Make a &amp;Donation</source>
        <translation>Buat &amp;Sumbangan</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="352"/>
        <source>&amp;Manually Start Playing</source>
        <translation>&amp;Mulai Memainkan secara Manual</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="353"/>
        <source>Manually start playing videos</source>
        <translation>Mulai memainkan video secara manual</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="848"/>
        <source>&amp;Play</source>
        <translation>&amp;Play</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="849"/>
        <source>Resume playback</source>
        <translation>Resume playback</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1055"/>
        <source>Remaining time: %1</source>
        <translation>Sisanya waktu: %1</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1113"/>
        <source>Volume at %1%</source>
        <translation>Volume at %1%</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1119"/>
        <source>Volume is muted</source>
        <translation>Volumenya adalah bisu</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1122"/>
        <source>Volume is unmuted</source>
        <translation>Volumenya tidak bisu</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1129"/>
        <source>Maximum video definition set to %1</source>
        <translation>Maksimumnya definisi video set ke %1</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1165"/>
        <source>Your privacy is now safe</source>
        <translation>Privasimu adalah aman sekarang</translation>
    </message>
    <message>
        <location filename="src/MainWindow.cpp" line="1180"/>
        <source>Downloads complete</source>
        <translation>Unduhan-unduhan komplit</translation>
    </message>
    <message>
        <location filename="local/mac/macsupport.cpp" line="58"/>
        <source>&amp;Window</source>
        <translation>&amp;Jendela</translation>
    </message>
    <message>
        <location filename="local/mac/macsupport.cpp" line="61"/>
        <source>&amp;Minimize</source>
        <translation>&amp;Minimalkan</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <location filename="src/MediaView.cpp" line="35"/>
        <source>Most relevant</source>
        <translation>Yang paling relevan</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="42"/>
        <source>Most recent</source>
        <translation>Most recent</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="49"/>
        <source>Most viewed</source>
        <translation>Yang paling banyak ditonton</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="521"/>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Sekarang Anda dapat paste link YouTube ke dalam aplikasi yang lain</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="529"/>
        <source>You can now paste the video stream URL into another application</source>
        <translation>You can now paste the video stream URL into another application</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="530"/>
        <source>The link will be valid only for a limited time.</source>
        <translation>Link akan berlaku hanya untuk waktu yang terbatas.</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="629"/>
        <source>This is just the demo version of %1.</source>
        <translation>This is just the demo version of %1.</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="630"/>
        <source>It allows you to test the application and see if it works for you.</source>
        <translation>Ini memungkinkan Anda untuk menguji aplikasi dan melihat apakah ia bekerja untuk Anda.</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="660"/>
        <source>Continue</source>
        <translation>Continue</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="749"/>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>dari</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="761"/>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>bagian</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="763"/>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>babak bagian</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="821"/>
        <source>Sent from %1</source>
        <translation>Dikirim dari %1</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="637"/>
        <source>Get the full version</source>
        <translation>Get the full version</translation>
    </message>
    <message>
        <location filename="src/MediaView.cpp" line="682"/>
        <source>Downloading %1</source>
        <translation>Downloading %1</translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <location filename="src/networkaccess.cpp" line="214"/>
        <source>Network error: %1</source>
        <translation>Network error: %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="170"/>
        <source>%1 views</source>
        <translation>%1 lihat-lihat</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="286"/>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 of %2 (%3) — %4</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="293"/>
        <source>Preparing</source>
        <translation>Persiapan</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="295"/>
        <source>Failed</source>
        <translation>Kesalahan</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="297"/>
        <source>Completed</source>
        <translation>Completed</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="299"/>
        <source>Stopped</source>
        <translation>Stopped</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="335"/>
        <source>Stop downloading</source>
        <translation>Berhenti mengunduh</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="345"/>
        <source>Show in %1</source>
        <translation>Tampilkan di %1</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="347"/>
        <source>Open parent folder</source>
        <translation>Open parent folder</translation>
    </message>
    <message>
        <location filename="src/playlist/PrettyItemDelegate.cpp" line="356"/>
        <source>Restart downloading</source>
        <translation>Mengulangi mengunduh</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <location filename="src/searchlineedit.cpp" line="177"/>
        <source>Search</source>
        <translation>Search</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <location filename="src/SearchView.cpp" line="79"/>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Selamat datang ke &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <location filename="src/SearchView.cpp" line="46"/>
        <source>Get the full version</source>
        <translation>Get the full version</translation>
    </message>
    <message>
        <location filename="src/SearchView.cpp" line="93"/>
        <source>Enter</source>
        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole frase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
        <translation>Masukkan</translation>
    </message>
    <message>
        <location filename="src/SearchView.cpp" line="98"/>
        <source>a keyword</source>
        <translation>sebuah kata kunci</translation>
    </message>
    <message>
        <location filename="src/SearchView.cpp" line="99"/>
        <source>a channel</source>
        <translation>a channel</translation>
    </message>
    <message>
        <location filename="src/SearchView.cpp" line="104"/>
        <source>to start watching videos.</source>
        <translation>to start watching videos.</translation>
    </message>
    <message>
        <location filename="src/SearchView.cpp" line="128"/>
        <source>Watch</source>
        <translation>Watch</translation>
    </message>
    <message>
        <location filename="src/SearchView.cpp" line="146"/>
        <source>Recent keywords</source>
        <translation>Recent keywords</translation>
    </message>
    <message>
        <location filename="src/SearchView.cpp" line="159"/>
        <source>Recent channels</source>
        <translation>Saluran-saluran saat ini</translation>
    </message>
    <message>
        <location filename="src/SearchView.h" line="26"/>
        <source>Make yourself comfortable</source>
        <translation>Make yourself comfortable</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <location filename="src/video.cpp" line="200"/>
        <source>Cannot get video stream for %1</source>
        <translation>Cannot get video stream for %1</translation>
    </message>
    <message>
        <location filename="src/video.cpp" line="218"/>
        <source>Network error: %1 for %2</source>
        <translation>Jaringan sedang error: %1 untuk %2</translation>
    </message>
</context>
</TS>